SETTINGS = {
    "sdk_version": "1.0.0",
    # "api_live_uri": "http://api.compropago.com/v1/",
    # "api_sandbox_uri": "http://api.compropago.com/v1/"

    "api_live_uri": "http://api-staging-compropago.herokuapp.com/v1/",
    "api_sandbox_uri": "http://api-staging-compropago.herokuapp.com/v1/"
}
