class InstructionDetails:
    amount = None
    store = None
    payment_amount = None
    payment_store = None
    bank_account_holder_name = None
    bank_account_number = None
    bank_reference = None
    company_reference_name = None
    company_reference_number = None
    company_bank_number = None
    order_reference_number = None
    bank_name = None

    def __init__(self):
        pass
