class Provider:
    name = None
    store_image = None
    is_active = None
    internal_name = None
    image_small = None
    image_medium = None
    image_large = None
    transaction_limit = None
    rank = None

    def __init__(self):
        pass
