class FeeDetails:
    amount = None
    currency = None
    type = None
    description = None
    application = None
    tax_percent = None
    amount_refunded = None
    tax = None

    def __init__(self):
        pass
